==> hermes-5.0.0.9.tar.gz: hermes-5.0.0.9/app/controllers/hermes/api/dmo/operations_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class OperationsController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          name
          code
          lessor_id
        ].freeze

        REGEX_PARAMS = %w[
          name
        ].freeze

        MUTATE_PARAMS = %i[
          name
          code
          lessor_id
        ].freeze
        mutate_params_only(*MUTATE_PARAMS)

        def set_instance
          @instance = nil
          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id).map(&:to_s)

          params[:name][:$regex]= /^#{::Regexp.escape(params[:name][:$regex]).accent_to_regexp}/i if params[:name] && params[:name][:$regex]

          if params[:id]
            @instance = @model.where({
              id: params[:id],
              '$or': [
                {lessor_id: { '$in': lessor_ids}},
                {lessor_id: nil},
              ]
            }).first
          end
        end

        def is_admin
          (
            @user.auth_roles&.include?('superadministrateur') || 
            @user.roles&.include?('Administrator') || 
            @user.roles&.include?('SuperAdmin') || 
            @user.roles&.include?('Manager')
          )
        end

        def create
          if !is_admin && (!mutate_valid_params[:lessor_id] || !Hermes::Lessor.find_by(id: mutate_valid_params[:lessor_id]).readable_by?(@user))
            return render_json_error(:unprocessable_entity, :cannot_create_without_lessor_id)
          end
          super
        end

        def user_can_destroy?
          if is_admin || (
            @instance.lessor_id && 
            Hermes::Lessor.find_by(id: @instance.lessor_id).readable_by?(@user)
          )
            return true
          end
          false
        end

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS

          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id)
          aggregation = index_aggregation(no_acl: true).where({
            '$or': [
              {lessor_id: { '$in': lessor_ids}},
              {lessor_id: nil},
            ] 
          })
          
          paginate(
            aggregation,
            each_serializer: @serializer,
            **@options
          )
        end
      end
    end
  end
end

==> hermes-5.3.0.10.tar.gz: hermes-5.3.0.10/app/controllers/hermes/api/dmo/operations_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class OperationsController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          name
          code
          lessor_id
        ].freeze

        REGEX_PARAMS = %w[
          name
        ].freeze

        MUTATE_PARAMS = %i[
          name
          code
          lessor_id
        ].freeze
        mutate_params_only(*MUTATE_PARAMS)

        def set_instance
          @instance = nil
          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id).map(&:to_s)

          params[:name][:$regex]= /#{::Regexp.escape(params[:name][:$regex]).accent_to_regexp}/i if params[:name] && params[:name][:$regex]

          if params[:id]
            @instance = @model.where({
              id: params[:id],
              '$or': [
                {lessor_id: { '$in': lessor_ids}},
                {lessor_id: nil},
              ]
            }).first
          end
        end

        def is_admin
          (
            @user.auth_roles&.include?('superadministrateur') || 
            @user.roles&.include?('Administrator') || 
            @user.roles&.include?('SuperAdmin') || 
            @user.roles&.include?('Manager')
          )
        end

        def create
          if !is_admin && (!mutate_valid_params[:lessor_id] || !Hermes::Lessor.find_by(id: mutate_valid_params[:lessor_id]).readable_by?(@user))
            return render_json_error(:unprocessable_entity, :cannot_create_without_lessor_id)
          end
          super
        end

        def user_can_destroy?
          if is_admin || (
            @instance.lessor_id && 
            Hermes::Lessor.find_by(id: @instance.lessor_id).readable_by?(@user)
          )
            return true
          end
          false
        end

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS

          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id)
          aggregation = index_aggregation(no_acl: true).where({
            '$or': [
              {lessor_id: { '$in': lessor_ids}},
              {lessor_id: nil},
            ] 
          })
          
          paginate(
            aggregation,
            each_serializer: @serializer,
            **@options
          )
        end
      end
    end
  end
end
